@@ -4,6 +4,7 @@ from typing import List
 from scipy.sparse.linalg import eigsh
 from karateclub.estimator import Estimator
 
+
 class SF(Estimator):
     r"""An implementation of `"SF" <https://arxiv.org/abs/1810.09155>`_
     from the NeurIPS Relational Representation Learning Workshop '18 paper "A Simple Baseline Algorithm for Graph Classification".
@@ -14,7 +15,8 @@ class SF(Estimator):
         dimensions (int): Number of lowest eigenvalues. Default is 128.
         seed (int): Random seed value. Default is 42.
     """
-    def __init__(self, dimensions: int=128, seed: int=42):
+
+    def __init__(self, dimensions: int = 128, seed: int = 42):
         self.dimensions = dimensions
         self.seed = seed
 
@@ -31,14 +33,26 @@ class SF(Estimator):
         number_of_nodes = graph.number_of_nodes()
         L_tilde = nx.normalized_laplacian_matrix(graph, nodelist=range(number_of_nodes))
         if number_of_nodes <= self.dimensions:
-            embedding = eigsh(L_tilde, k=number_of_nodes-1, which='LM',
-                              ncv=10*self.dimensions, return_eigenvectors=False)
+            embedding = eigsh(
+                L_tilde,
+                k=number_of_nodes - 1,
+                which="LM",
+                ncv=10 * self.dimensions,
+                return_eigenvectors=False,
+            )
 
             shape_diff = self.dimensions - embedding.shape[0] - 1
-            embedding = np.pad(embedding, (1, shape_diff), 'constant', constant_values=0)
+            embedding = np.pad(
+                embedding, (1, shape_diff), "constant", constant_values=0
+            )
         else:
-            embedding = eigsh(L_tilde, k=self.dimensions, which='LM',
-                              ncv=10*self.dimensions, return_eigenvectors=False)
+            embedding = eigsh(
+                L_tilde,
+                k=self.dimensions,
+                which="LM",
+                ncv=10 * self.dimensions,
+                return_eigenvectors=False,
+            )
         return embedding
 
     def fit(self, graphs):
@@ -52,7 +66,6 @@ class SF(Estimator):
         graphs = self._check_graphs(graphs)
         self._embedding = [self._calculate_sf(graph) for graph in graphs]
 
-
     def get_embedding(self) -> np.array:
         r"""Getting the embedding of graphs.
 
